local tablet = AceLibrary("Tablet-2.0")
FishingFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceEvent-2.0", "AceDB-2.0", "AceDebug-2.0", "AceConsole-2.0")
FishingFu:RegisterDB("FishingFuDB", "FishingFuPCDB")
FishingFu.hasIcon = "Interface/Icons/Trade_Fishing.blp"

FishingFu:RegisterDefaults("char", {
  LastFishingValue = 0,
  FishSinceLastSkillUp = 0,
})

function FishingFu:OnInitialize()
end

function FishingFu:OnEnable()
  self:RegisterEvent("PLAYER_LOGIN")
  self:RegisterEvent("CHAT_MSG_SKILL")
  self:RegisterEvent("LOOT_OPENED")
  self:RegisterEvent("UNIT_INVENTORY_CHANGED")
end

function FishingFu:OnDisable()
end

function FishingFu:PLAYER_LOGIN()
  self:Update()
end

function FishingFu:LOOT_OPENED()
  if(IsFishingLoot()) then
    self.db.char.FishSinceLastSkillUp = self.db.char.FishSinceLastSkillUp + 1
    if(self:EstimateNextPoint() > 1) then
      self:Print("Fishing Loot (" .. self.db.char.FishSinceLastSkillUp .. ")")
    end
  end
end

function FishingFu:UNIT_INVENTORY_CHANGED(unitId)
  if(unitId == "player") then
    self:Update()
  end
end

function FishingFu:CHAT_MSG_SKILL()
  self:Update()
end

function FishingFu:EstimateNextPoint()
  r = ((self.db.char.LastFishingValue - 75) / 25) + 1
  if(r<1) then
    r = 1
  end
  return r
end

function FishingFu:OnSkillUp(skill)
  self.db.char.LastFishingValue = skill
  self.db.char.FishSinceLastSkillUp = 0
  local estimate = self:EstimateNextPoint()
  if(estimate > 1) then
    self:Print("Next Skill Point in " .. estimate .. " catches")
  end
end

function FishingFu:GetFishingInfo()
  local numSkills = GetNumSkillLines();
  for i=1, numSkills do
    local skillName, isHeader = GetSkillLineInfo(i)
    if(not isHeader and skillName == "Fishing") then
      return GetSkillLineInfo(i)
    end
  end
end

function FishingFu:OnDataUpdate()
  local skillName, isHeader, isExpanded, skillRank = self:GetFishingInfo()
  if(skillName ~= nil) then
    if(self.db.char.LastFishingValue ~= skillRank) then
      self:OnSkillUp(skillRank)
    end
  end
end

function FishingFu:OnTextUpdate()
  local skillName, isHeader, isExpanded, skillRank, numTempPoints, skillModifier, skillMaxRank = self:GetFishingInfo()
  if(skillName == nil) then
    self:SetText("-")
    return
  end
  local title = "|cFFFFFF99" .. skillName
  if(skillRank < skillMaxRank) then
    title = title .. " |cFFFFFFFF" .. skillRank .. "/" .. skillMaxRank
  else
    title = title .. " |cFFFFFFFF" .. skillRank
  end
  if(skillModifier > 0) then
    title = title .. "|cFF00FF00(+" .. skillModifier .. ")"
  end
  if(skillRank < skillMaxRank) then
    title = title .. " |cFFFF0000" .. "~" .. self.db.char.FishSinceLastSkillUp .. "/" .. self:EstimateNextPoint()
  end
  title = title .. "|r"
  self:SetText(title)
end

--function FishingFu:OnTooltipUpdate()
--end
